@@ -18,9 +18,9 @@ arg_enum! {
   }
 }
 
-fn main() -> Result<(), Box<dyn Error>> {
+fn main() {
     let matches = App::new("Ender")
-        .version("2.0.0-20210823.0")
+        .version("2.1.2+20210904.0")
         .author("John Lyon-Smith")
         .about("End of line normalizer.  Defaults to reporting types of endings.")
         .arg(
@@ -59,9 +59,8 @@ fn main() -> Result<(), Box<dyn Error>> {
 
     if let Err(ref err) = result {
         eprintln!("error: {}", err);
+        std::process::exit(-1);
     }
-
-    result
 }
 // {grcov-excl-end}
 
@@ -76,7 +75,7 @@ fn run(
     print!(
         "'{}', {}, {} lines",
         input_file,
-        if eol_info.num_endings > 1 {
+        if eol_info.num_endings() > 1 {
             "mixed"
         } else if eol_info.cr > 0 {
             "cr"
