@@ -17,9 +17,9 @@ arg_enum! {
   }
 }
 
-fn main() -> Result<(), Box<dyn Error>> {
+fn main() {
     let matches = App::new("Spacer")
-        .version("2.0.0-20210823.0")
+        .version("2.1.2+20210904.0")
         .author("John Lyon-Smith")
         .about(
             "Beginning of line normalizer. Defaults to reporting types count of spaces, tab and mixed beginnings.",
@@ -69,15 +69,14 @@ fn main() -> Result<(), Box<dyn Error>> {
         matches.value_of("input_file").unwrap(),
         matches.value_of("output_file"),
         value_t!(matches, "bol_arg", BeginningOfLineArg).ok(),
-        usize::from_str_radix(matches.value_of("tab_size").unwrap(), 10)?,
+        usize::from_str_radix(matches.value_of("tab_size").unwrap(), 10).unwrap_or(4),
         matches.is_present("round_down"),
     );
 
     if let Err(ref err) = result {
         eprintln!("error: {}", err);
+        std::process::exit(-1);
     }
-
-    result
 }
 // {grcov-excl-end}
 
@@ -195,7 +194,7 @@ mod tests {
         let input_path = temp_dir.path().join("input_file.txt");
         let input_file = input_path.to_str().unwrap();
 
-        std::fs::write(input_file, "\t\t abc\r").unwrap();
+        std::fs::write(input_file, "\t\n\t\n\t\t abc\r").unwrap();
 
         run(
             input_file,
